#!/usr/bin/ksh
#####################################################################################################
#
# Shell script to monitor the file systems on the AIX server. It will read from a properties file
# named space_monitor_config.properties resides in the same directory of this shell script.
# The properties file contains the configuration information regarding what file systems
# you want to be monitored, each line defines the file system and it's threshold of used
# percentage in the format of:  filesystem=percentage%(example: /apps/zel0/log=90%  this
# would mean once the file system/mounting point space is reaching 90% full and over, an Alert
# email would be sent to the email list defined in the same properties file:
# ALERT_EMAIL_LIST=fang@abc.com;mike.burk@abc.com
#
# If the properties file is not existing or not readable, it will prompt the user if it should run
# in default mode, in which all the file systems will be monitored and if there's any reaching
# 90% full or over, email alert will be sent to an address in the code below.(DEFAULT_EMAIL_LIST)
# The default mode function is more for Unix admin to use for general purpose of space monitoring.
# Currently the default mode function is disabled to provide simplicity for the end user.
#
# This is the wraper shell calls the watch_file_system.sh which does the major
# job. Basically it checks if there's already a running process monitoring the
# file system, if yes it will quit running, otherwise it will start the monitor.
#
# Config file     : space_monitor_config.properties
# Log file        : space_monitor.log
#
# Operating system: AIX Version 5.3
# Initial Version : Fang
# Date            : Oct 20, 2009
#
# Change History:
#   Date               Name                Summary
# ---------    --------------------     ----------------------------------------------
#
#
# 
#####################################################################################################
         
#check if there is any running process already.
isRunning=`ps -ef | grep watch_file_system | grep -Ev 'grep|vi|cat|tail'`

if [ -z "$isRunning" ]
then

      echo "\n Space monitor program running, please check space_monitor.log for running details.\n" 
      while [ 1=1 ]
      do
             ./watch_file_system.sh  1>> $PWD/space_monitor.log 2>&1
             sleep 1
      done

else

     echo "The space monitor program is running already."
     echo "$isRunning"
     exit 0
fi

